/* Stata program to read in the Mullahy data set */

/* The data in the file mullahy_1998.dat is an extract from the 
1992 National Health Interview Survey constructed by John Mullahy for 
his paper 


Mullahy J. 1998. "Much Ado About Two: Reconsidering Retransformation and 
the Two-Part Model in Health Econometrics."  
Journal of Health Economics 17: 247-281. 
DOI:10.1016/S0167-6296(98)00030-7


These data are space delimited can be read into Stata with the command 

infile 
age educ poverty famsize docvisits12 male white married 
working school xcellent verygood good fair 
using mullahy_1998.dat ;   /* this file's size is approximately 5,431Kb */ 

 
See the stata do file Read_Mullahy_data.do which reads in the data set and 
estimates a simple poisson model for the determinants of dioctor visits over 
the past 12 months.


The variable names are mostly self-explanatory, and there is 
one excluded health status category.   

Summary statistics for the Mullahy data set:

    Variable |       Obs        Mean    Std. Dev.       Min        Max
-------------+--------------------------------------------------------
         age |     36111    41.76287     10.9192         25         64
        educ |     36111    12.96749    2.958055          0         18
     poverty |     36111    1.112736    .3162739          1          2
     famsize |     36111     2.88912     1.51095          1         15
 docvisits12 |     36111    4.910166    12.80193          0        370
-------------+--------------------------------------------------------
        male |     36111    .3780842    .4849155          0          1
       white |     36111    .8190025    .3850214          0          1
     married |     36111    .6808452    .4661556          0          1
     working |     36111    .7057683    .4557029          0          1
      school |     36111    .0212401    .1441856          0          1
-------------+--------------------------------------------------------
    xcellent |     36111    .3418349    .4743311          0          1
    verygood |     36111    .3004625    .4584655          0          1
        good |     36111    .2414223    .4279517          0          1
        fair |     36111    .0846556    .2783724          0          1

*/





drop _all
#delimit ;

infile 
age educ poverty famsize docvisits12 male white married 
working school xcellent verygood good fair 
using mullahy_1998.dat ; 

summarize;

poisson docvisits12 
age educ poverty famsize male white married 
working school xcellent verygood good fair ;

